////////////////////////////////////////////////////////////////////////////////
/// -NOTES- ////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////
// This package contains functions and datablocks that make a trigger
// damage a player when they enter it. This does have some bugs due to
// the way Tribes 2 handles vehicles and triggers. If the player is in
// a vehicle when he enters the trigger, nothing will happen. Also if a
// player enters a vehicle while in the trigger then flys out of the trigger
// the player will still take damage. This is because vehicles cannot trip 
// triggers. The is no altered base code here so we need not package anything.
////////////////////////////////////////////////////////////////////////////////
/// These globals go in the map.cs file to customize the functions.
/// DO NOT UN-REM THE ONES HERE. ADD THEM TO YOUR MAP.CS FILE.
////////////////////////////////////////////////////////////////////////////////
// Enter and leave trigger messages
// $Map::onEnterTrigger = "\c0You got stuck in whatever the hell it is!";
// $Map::onleaveTrigger = "\c0You have left the whatever the hell it is.";
//
// Random death messages
// $Map::KillMsg0 = "\c0You died from whatever the hell it is!";
// $Map::KillMsg1 = "\c0You died from whatever the hell it is x2!";
// $Map::KillMsg2 = "\c0You died from whatever the hell it is x3!";
//
// Damage effects and amounts
// $Map::DamageEffect = 1; // Set to 1 for whiteout or 0 for red flash
// $Map::DamageVisual = 1; // Set to one to enable shield effect visual
// $Map::DamageAmount = 0.01; // Amount of damage to apply
////////////////////////////////////////////////////////////////////////////////
// The trigger that gets placed in the *.mis file should look
// something like this:
// new Trigger() {
//    position = "252.32 660.155 382.398";
//    rotation = "1 0 0 0";
//    scale = "250.246 250.0131 44.5011";
//    dataBlock = "MapDamageTrigger"; // This is the must have part
//    lockCount = "0";
//    homingCount = "0";
//    polyhedron = "-0.75 0.75 0.1 1.5 0.0 0.0 0.0 -1.5 0.0 0.0 0.0 2.3";
// };
////////////////////////////////////////////////////////////////////////////////
/// -Player Damage trigger functions and datablocks- ///////////////////////////
////////////////////////////////////////////////////////////////////////////////

datablock TriggerData(MapDamageTrigger)
{
   tickPeriodMS = 30;
};

function MapDamageTrigger::onEnterTrigger(%data, %trigger, %player)
{
   %player.hurt = 1;
   messageClient(%player.client, 'MsgClient', $Map::onEnterTrigger);
   hurtplayer(%player);
}

function MapDamageTrigger::onleaveTrigger(%data, %trigger, %player)
{
   %player.hurt = 0;
   if (!isObject(%player) || %player.getState() $= "Dead")
       return;
   messageClient(%player.client, 'MsgClient', $Map::onleaveTrigger);
}

function MapDamageTrigger::onTickTrigger(%data, %obj)
{
   Game.onTickTrigger(%obj.name, %data, %obj);
}

function hurtplayer(%player)
{
   if(%player.hurt == 0)
      return;

   if (!isObject(%player) || %player.getState() $= "Dead")
   {
      %ran = getRandom();
      if(%ran > 0.7)
         messageClient(%player.client, 'MsgClient', $Map::KillMsg0);
      else if(%ran > 0.3)
         messageClient(%player.client, 'MsgClient', $Map::KillMsg1);
      else
         messageClient(%player.client, 'MsgClient', $Map::KillMsg2);

      %game = Game.getId();
      %damLoc = %player.getPosition();
      DefaultGame::onClientKilled(%game, %player.client, "", $DamageType::Default, "", %damLoc);
      %player.hurt = 0;
      return;
   }
   else
   {
      if($Map::DamageEffect == 1)
         %player.setWhiteOut(0.5); // White flash
      else
         %player.setDamageFlash(0.5); // Red flash

      if($Map::DamageVisual)
      {
         %norm = "1.0 0.0 0.0";
         %player.playShieldEffect( %norm );
      }
      %player.damage(0, %player.position, $Map::DamageAmount, $DamageType::Default);
      schedule(1000,0,"hurtplayer",%player);
   }
}

////////////////////////////////////////////////////////////////////////////////
